"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.arrayForEachRange = void 0;
const _debug_js_1 = require("../../debug/_debug.js");
/**
 * @public
 * Like {@link arrayForEach} with integer range as input.
 *
 * @param from - The value to start from (inclusive).
 * @param to - The value to finish with (inclusive).
 * @param callback - Called for each value in the range.
 *
 * @remarks
 * Where `from` and `to` are equal a length 1 array is returned, NaN input is not supported.
 *
 * See {@link arrayForEachRange}.
 */
function arrayForEachRange(from, to, callback) {
    _BUILD.DEBUG && _debug_js_1._Debug.runBlock(() => {
        _debug_js_1._Debug.assert(!isNaN(from) && !isNaN(to), "NaN range not supported");
    });
    const range = to - from;
    const increment = Math.sign(range);
    for (let i = 0; i < Math.abs(range) + 1; ++i) {
        callback(from, i);
        from += increment;
    }
}
exports.arrayForEachRange = arrayForEachRange;
//# sourceMappingURL=array-for-each-range.js.map