"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMat2Ctor = void 0;
const mat2_factory_js_1 = require("./mat2-factory.js");
const _debug_js_1 = require("../../../debug/_debug.js");
const normalized_data_view_provider_js_1 = require("../normalized-data-view/normalized-data-view-provider.js");
const vec2_js_1 = require("../vec2/vec2.js");
/**
 * @internal
 */
function getMat2Ctor(ctor) {
    var _a;
    return _a = class Mat2Impl extends ctor {
            constructor(bufferOrLength = 4, offset, length) {
                super(bufferOrLength, offset, length);
            }
            isEqualTo(other) {
                return this[0] === other[0] && this[1] === other[1] && this[2] === other[2] && this[3] === other[3];
            }
            update(a1, a2, a3, a4) {
                this[0] = a1;
                this[1] = a2;
                this[2] = a3;
                this[3] = a4;
            }
            setIdentityMatrix() {
                this[0] = 1;
                this[1] = 0;
                this[2] = 0;
                this[3] = 1;
                return this;
            }
            getValueAt(column, row) {
                _BUILD.DEBUG && _debug_js_1._Debug.assert(column >= 0 && column < 2 && row >= 0 && row < 2, "out of bounds");
                return this[row * 2 + column];
            }
            setValueAt(column, row, value) {
                _BUILD.DEBUG && _debug_js_1._Debug.assert(column >= 0 && column < 2 && row >= 0 && row < 2, "out of bounds");
                this[row * 2 + column] = value;
            }
            setScalingMatrix(scalingFactor) {
                this[0] = scalingFactor;
                this[1] = 0;
                this[2] = 0;
                this[3] = 1;
                return this;
            }
            setTranslationMatrix(translation) {
                this[0] = 1;
                this[1] = 0;
                this[2] = translation;
                this[3] = 1;
                return this;
            }
            multiplyMat2(mat, result = this.constructor.factory.createOneEmpty()) {
                const [a0, a1, a2, a3] = this;
                const [b0, b1, b2, b3] = mat;
                result[0] = a0 * b0 + a1 * b2;
                result[1] = a0 * b1 + a1 * b3;
                result[2] = a2 * b0 + a3 * b2;
                result[3] = a2 * b1 + a3 * b3;
                return result;
            }
            getVec2MultiplyX(x) {
                return this[0] * x + this[2];
            }
            scalarMultiply(value, result = this.constructor.factory.createOneEmpty()) {
                result[0] = this[0] * value;
                result[1] = this[1] * value;
                result[2] = this[2] * value;
                result[3] = this[3] * value;
                return result;
            }
            scalarAdd(value, result = this.constructor.factory.createOneEmpty()) {
                result[0] = this[0] + value;
                result[1] = this[1] + value;
                result[2] = this[2] + value;
                result[3] = this[3] + value;
                return result;
            }
            getRow(row, writeTo = this.constructor.vec2Ctor.factory.createOneEmpty()) {
                _BUILD.DEBUG && _debug_js_1._Debug.assert(row >= 0 && row < 2, "index out of bounds");
                writeTo[0] = this.getValueAt(0, row);
                writeTo[1] = this.getValueAt(1, row);
                return writeTo;
            }
            setRow(row, writeFrom) {
                _BUILD.DEBUG && _debug_js_1._Debug.assert(row >= 0 && row < 2, "index out of bounds");
                this.setValueAt(0, row, writeFrom[0]);
                this.setValueAt(1, row, writeFrom[1]);
            }
            getLoggableValue() {
                return [
                    [this[0], this[1]],
                    [this[2], this[3]],
                ];
            }
            copyFromBuffer(memoryDataView, pointer, littleEndian) {
                this.constructor.factory.copyFromBuffer(memoryDataView, pointer, this, littleEndian);
            }
            copyToBuffer(memoryDataView, pointer, littleEndian) {
                this.constructor.factory.copyToBuffer(memoryDataView, this, pointer, littleEndian);
            }
            castToBaseType() {
                return this;
            }
        },
        _a.factory = new mat2_factory_js_1.Mat2Factory(_a, normalized_data_view_provider_js_1.NormalizedDataViewProvider.getView(ctor)),
        _a.vec2Ctor = vec2_js_1.Vec2.getCtor(ctor),
        _a;
}
exports.getMat2Ctor = getMat2Ctor;
//# sourceMappingURL=get-mat2-ctor.js.map