"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRange1dCtor = void 0;
const normalized_data_view_provider_js_1 = require("../../normalized-data-view/normalized-data-view-provider.js");
const _debug_js_1 = require("../../../../debug/_debug.js");
const get_vec2_ctor_js_1 = require("../get-vec2-ctor.js");
const vec2_factory_js_1 = require("../vec2-factory.js");
const mat2_js_1 = require("../../mat2/mat2.js");
/**
 * @internal
 */
function getRange1dCtor(ctor) {
    var _a;
    return _a = class Range1dImpl extends (0, get_vec2_ctor_js_1.getVec2Ctor)(ctor) {
            setMin(value) {
                this[0] = value;
            }
            setMax(value) {
                this[1] = value;
            }
            getMin() {
                return this[0];
            }
            getMax() {
                return this[1];
            }
            getRange() {
                return this[1] - this[0];
            }
            getCenter() {
                return (this[0] + this[1]) * 0.5;
            }
            mat2Multiply(mat, writeTo = this.constructor.factory.createOneEmpty()) {
                writeTo.setMin(mat.getVec2MultiplyX(this.getMin()));
                writeTo.setMax(mat.getVec2MultiplyX(this.getMax()));
                return writeTo;
            }
            unionRange(range, writeTo = this.constructor.factory.createOneEmpty()) {
                writeTo[0] = this[0] > range[0] ? range[0] : this[0];
                writeTo[1] = this[1] < range[1] ? range[1] : this[1];
                return writeTo;
            }
            extendRange(value, writeTo = this.constructor.factory.createOneEmpty()) {
                writeTo[0] = this[0] > value ? value : this[0];
                writeTo[1] = this[1] < value ? value : this[1];
                return writeTo;
            }
            getRangeTransform(toRange, result = this.constructor.mat2Ctor.factory.createOneEmpty()) {
                _BUILD.DEBUG && _debug_js_1._Debug.assert(this.getRange() !== 0, "divide by 0");
                const sf = toRange.getRange() / this.getRange();
                result[0] = sf;
                result[1] = 0;
                result[2] = toRange.getMin() - this.getMin() * sf;
                result[3] = 1;
                return result;
            }
            isValueInRange1d(value) {
                return value >= this.getMin() && value <= this.getMax();
            }
            scaleRelativeTo(scalingFactor, relativeTo, result = this.constructor.factory.createOneEmpty()) {
                _BUILD.DEBUG && _debug_js_1._Debug.assert(this.isValueInRange1d(relativeTo), "relativeTo must be inside the range");
                let difference = this.getCenter() - relativeTo;
                // multiply by 2 as we want to compare to half the range
                // make the difference relative, varies from -1 to 1
                difference = 2 * difference / this.getRange();
                const newRange = this.getRange() * scalingFactor;
                const halfDiff = 0.5 * (this.getRange() - newRange);
                const newMin = this.getMin() + halfDiff - halfDiff * difference;
                result.setMin(newMin);
                result.setMax(newMin + newRange);
                return result;
            }
            bound1d(boundTo) {
                if (this.getRange() > boundTo.getRange()) {
                    this.setMin(boundTo.getMin());
                    this.setMax(boundTo.getMax());
                }
                else if (this.getMax() > boundTo.getMax()) {
                    const range = this.getRange();
                    this.setMax(boundTo.getMax());
                    this.setMin(boundTo.getMax() - range);
                }
                else if (this.getMin() < boundTo.getMin()) {
                    const range = this.getRange();
                    this.setMin(boundTo.getMin());
                    this.setMax(boundTo.getMin() + range);
                }
            }
            translate1d(dv) {
                this.setMin(this.getMin() + dv);
                this.setMax(this.getMax() + dv);
            }
        },
        _a.factory = new vec2_factory_js_1.Vec2Factory(_a, normalized_data_view_provider_js_1.NormalizedDataViewProvider.getView(ctor)),
        _a.mat2Ctor = mat2_js_1.Mat2.getCtor(ctor),
        _a;
}
exports.getRange1dCtor = getRange1dCtor;
//# sourceMappingURL=get-range1d-ctor.js.map