import { IDebugSharedObject } from "./i-debug-shared-object.js";
/**
 * @public
 * Wrapper of {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/FinalizationRegistry|FinalizationRegistry} for shared objects,
 * useful for checking if the shared object was properly disposed. Available in debug contexts only.
 */
export interface IDebugSharedObjectLifeCycleChecker {
    registerFinalizationCheck(sharedObject: IDebugSharedObject): void;
    markReadyForFinalize(sharedObject: IDebugSharedObject): void;
}
/**
 * When a javascript object is garbage collected, check if the corresponding WASM object has been freed.
 */
export declare class DebugSharedObjectLifeCycleChecker implements IDebugSharedObjectLifeCycleChecker {
    registerFinalizationCheck(sharedObject: IDebugSharedObject): void;
    markReadyForFinalize(sharedObject: IDebugSharedObject): void;
    private finalizationRegistry;
    private owningPointers;
    private sharedObjToPtr;
    private debugPointers;
}
