/**
 * @public
 * An error which can have a chain of causes.
 */
export interface INestedError<TLocalization> {
    readonly stack: string;
    getMessage(): TLocalization;
    readonly causedBy: unknown;
}
/**
 * @public
 * Constructor to {@link INestedError}.
 */
export interface INestedErrorCtor<TLocalization, TInstance extends INestedError<TLocalization>> {
    new (message: TLocalization, causedBy: unknown): TInstance;
    isError(error: unknown): error is TInstance;
    getRootCause(error: unknown): TInstance;
    normalizeError(error: unknown): TInstance;
}
/**
 * @public
 * The config used to create `NestedError` constructors, used by {@link getNestedErrorCtor}.
 */
export interface INestedErrorCtorConfig<ILocalization> {
    /**
     * Given a localization, convert it to a somewhat human-readable string. This should NOT be using any localization system
     * if there's any chance it can fail to load. This is intended for cases where the localization system is not available.
     */
    getTxFallback: (localization: ILocalization) => string;
    /**
     * In the event that an error is not an extensions of this class, this message will be used.
     */
    defaultError: ILocalization;
}
/**
 * @public
 * Factory for creating a localized `NestedError` class, see {@link INestedError}. This should be used
 * to create a base class, from which you can create extensions to represent specific error cases.
 */
export declare function getNestedErrorCtor<TLocalization>(config: INestedErrorCtorConfig<TLocalization>): INestedErrorCtor<TLocalization, INestedError<TLocalization>>;
