"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNestedErrorCtor = void 0;
const _debug_js_1 = require("../debug/_debug.js");
/**
 * @public
 * Factory for creating a localized `NestedError` class, see {@link INestedError}. This should be used
 * to create a base class, from which you can create extensions to represent specific error cases.
 */
function getNestedErrorCtor(config) {
    var _a;
    return _a = class NestedError {
            static isError(error) {
                return error instanceof this;
            }
            static normalizeError(error) {
                if (NestedError.isError(error)) {
                    return error;
                }
                return new NestedError(NestedError.ctorConfig.defaultError, error);
            }
            static getRootCause(error) {
                const normalizedError = NestedError.normalizeError(error);
                if (NestedError.isError(normalizedError.causedBy)) {
                    return NestedError.getRootCause(normalizedError.causedBy);
                }
                else {
                    return normalizedError;
                }
            }
            constructor(message, causedBy) {
                this.message = message;
                this.causedBy = causedBy;
                this.stack = _debug_js_1._Debug.getStackTrace();
            }
            getMessage() {
                return this.message;
            }
            toString() {
                return [
                    NestedError.ctorConfig.getTxFallback(this.message),
                    this.stack,
                ].join("\n");
            }
        },
        _a.ctorConfig = config,
        _a;
}
exports.getNestedErrorCtor = getNestedErrorCtor;
//# sourceMappingURL=nested-error-factory.js.map