"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BroadcastEvent = void 0;
const _set_js_1 = require("../set/_set.js");
/**
 * @public
 * Strong reference implementation of {@link IBroadcastEvent}.
 */
class BroadcastEvent {
    constructor(key) {
        this.key = key;
        this.listeners = new Set();
        this.cache = null;
    }
    addListener(listener) {
        this.listeners.add(listener);
        this.cache = null;
    }
    addTemporaryListener(listener) {
        this.listeners.add(listener);
        this.cache = null;
        return () => this.removeListener(listener);
    }
    addOneTimeListener(listener) {
        const temporaryListener = {
            [this.key]: (...args) => {
                this.removeListener(temporaryListener);
                return listener[this.key](...args);
            }
        };
        this.addListener(temporaryListener);
        return () => this.removeListener(temporaryListener);
    }
    removeListener(listener) {
        this.listeners.delete(listener);
        this.cache = null;
    }
    emit(...args) {
        this.listeners.forEach(listener => listener[this.key](...args));
    }
    getTargets() {
        if (this.cache == null) {
            return this.cache = _set_js_1._Set.valuesToArray(this.listeners);
        }
        else {
            return this.cache;
        }
    }
}
exports.BroadcastEvent = BroadcastEvent;
//# sourceMappingURL=broadcast-event.js.map