"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AReferenceCounted = void 0;
const _debug_js_1 = require("../debug/_debug.js");
const linked_references_js_1 = require("./linked-references.js");
const temporary_listener_js_1 = require("./temporary-listener.js");
/**
 * @public
 * Provides a way to handle cleanup of manually managed resources where there is not a single owner.
 * NB The object is pre-claimed (ref count 1) on creation.
 */
class AReferenceCounted {
    constructor() {
        this.references = 1;
        this.linkedReferences = null;
        this.onFreeListener = null;
    }
    /**
     * Take a claim on the object, preventing it from being destroyed. Once you're done with the object you should
     * call `release`.
     */
    claim() {
        if (this.references === 0) {
            _BUILD.DEBUG && _debug_js_1._Debug.error("object has been released already");
            return;
        }
        ++this.references;
    }
    /**
     * Release claim on the object, objects start with a reference count of 1 (the creator); if you didn't create the
     * object, you shouldn't release it if you didn't call `claim` first.
     */
    release() {
        if (--this.references === 0) {
            this.onFree();
        }
    }
    getIsDestroyed() {
        return this.references <= 0;
    }
    getLinkedReferences() {
        if (this.linkedReferences == null) {
            return this.linkedReferences = new linked_references_js_1.LinkedReferences(this);
        }
        return this.linkedReferences;
    }
    registerOnFreeListener(callback) {
        var _a;
        this.onFreeListener = (_a = this.onFreeListener) !== null && _a !== void 0 ? _a : new temporary_listener_js_1.TemporaryListener();
        this.onFreeListener.addListener(callback);
    }
    unregisterOnFreeListener(callback) {
        if (this.onFreeListener) {
            this.onFreeListener.removeListener(callback);
        }
    }
    /**
     * DO NOT CALL THIS DIRECTLY, CALL RELEASE.
     */
    onFree() {
        var _a, _b;
        (_a = this.linkedReferences) === null || _a === void 0 ? void 0 : _a.unlinkAllRefs();
        (_b = this.onFreeListener) === null || _b === void 0 ? void 0 : _b.clearingEmit();
    }
}
exports.AReferenceCounted = AReferenceCounted;
//# sourceMappingURL=a-reference-counted.js.map