"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.blockScopedLifecycle = void 0;
const lifecycle_stack_js_1 = require("../web-assembly/emscripten/lifecycle-stack.js");
/**
 * @public
 * Any shared objects allocated in the callback will be released on return. By default, these will be released on throw too.
 * In such event the error will be rethrown after releasing any shared objects.
 *
 * Error handling can be disabled by setting the build flag `WASM_DISABLE_STACK_LIFECYCLE_TRY_CATCH`.
 */
function blockScopedLifecycle(callback) {
    const refs = lifecycle_stack_js_1.lifecycleStack.push();
    let ret;
    // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
    if (_BUILD.WASM_DISABLE_STACK_LIFECYCLE_TRY_CATCH) {
        ret = callback();
        releaseRefs(refs);
        lifecycle_stack_js_1.lifecycleStack.pop();
    }
    else {
        try {
            ret = callback();
            releaseRefs(refs);
        }
        finally {
            lifecycle_stack_js_1.lifecycleStack.pop();
        }
    }
    return ret;
}
exports.blockScopedLifecycle = blockScopedLifecycle;
function releaseRefs(refs) {
    for (let i = 0, iEnd = refs.length; i < iEnd; ++i) {
        refs[i].release();
    }
}
//# sourceMappingURL=block-scoped-lifecycle.js.map