"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LinkedReferences = void 0;
const dirty_checked_unique_collection_js_1 = require("../collection/dirty-checked-unique-collection.js");
const _debug_js_1 = require("../debug/_debug.js");
/**
 * @public
 * {@inheritDoc ILinkedReferences}
 */
class LinkedReferences {
    constructor(ref) {
        this.ref = ref;
        this.refs = new dirty_checked_unique_collection_js_1.DirtyCheckedUniqueCollection();
    }
    linkRef(ref) {
        if (!this.refs.has(ref)) {
            if (_BUILD.DEBUG) {
                _debug_js_1._Debug.assert(!DEBUG_getHasCycle(this.ref, ref), "detected cycle between references");
                _debug_js_1._Debug.assert(!ref.getIsDestroyed() && !this.ref.getIsDestroyed(), "attempted to link to dead ref");
            }
            this.refs.add(ref);
            ref.claim();
        }
        return this;
    }
    unlinkRef(ref) {
        const removed = this.refs.delete(ref);
        if (removed) {
            ref.release();
        }
        return this;
    }
    unlinkAllRefs() {
        this.clearRefs();
    }
    clearRefs() {
        const refs = this.refs.getArray();
        for (let i = 0, iEnd = refs.length; i < iEnd; ++i) {
            refs[i].release();
        }
        this.refs.clear();
    }
    refsToArray() {
        return this.refs.getArray();
    }
}
exports.LinkedReferences = LinkedReferences;
function DEBUG_getHasCycle(referencingTo, referencingFrom) {
    if (referencingTo === referencingFrom) {
        return true;
    }
    const refs = referencingFrom
        .getLinkedReferences()
        .refsToArray();
    for (let i = 0, iEnd = refs.length; i < iEnd; ++i) {
        if (DEBUG_getHasCycle(referencingTo, refs[i])) {
            return true;
        }
    }
    return false;
}
//# sourceMappingURL=linked-references.js.map