"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEmscriptenWrapper = void 0;
const tslib_1 = require("tslib");
const shim_web_assembly_memory_js_1 = require("../util/shim-web-assembly-memory.js");
const broadcast_event_js_1 = require("../../eventing/broadcast-event.js");
const _debug_js_1 = require("../../debug/_debug.js");
const debug_weak_broadcast_event_js_1 = require("../../debug/debug-weak-broadcast-event.js");
const debug_shared_object_life_cycle_checker_js_1 = require("../../debug/debug-shared-object-life-cycle-checker.js");
const debug_weak_value_js_1 = require("../../debug/debug-weak-value.js");
const array_empty_array_js_1 = require("../../array/impl/array-empty-array.js");
/**
 * @public
 * Factory for creating wrapped emscripten module.
 */
function getEmscriptenWrapper(memory, emscriptenModuleFactory, extension = {}) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const memoryListener = _BUILD.DEBUG
            ? new debug_weak_broadcast_event_js_1.DebugWeakBroadcastEvent("onMemoryResize")
            : new broadcast_event_js_1.BroadcastEvent("onMemoryResize");
        const debug = new EmscriptenDebug();
        if (_BUILD.DEBUG) {
            const debugInstance = extension;
            debugInstance.RC_JS_MEMORY_DEBUG_UTIL = debug;
        }
        const instance = yield emscriptenModuleFactory(Object.assign({ wasmMemory: memory }, extension));
        return new EmscriptenWrapper(memoryListener, instance, memory, debug);
    });
}
exports.getEmscriptenWrapper = getEmscriptenWrapper;
class EmscriptenWrapper {
    constructor(memoryResize, instance, memory, debug) {
        this.memoryResize = memoryResize;
        this.instance = instance;
        this.memory = memory;
        this.debug = debug;
        this.dataView = new DataView(memory.buffer);
        (0, shim_web_assembly_memory_js_1.shimWebAssemblyMemory)(memory, (buffer, previous, delta) => {
            _BUILD.DEBUG && _debug_js_1._Debug.verboseLog(["WASM", "MEMORY"], `WebAssembly memory grew from ${previous} to ${previous + delta} pages.`);
            this.dataView = new DataView(this.memory.buffer);
            this.memoryResize.emit(buffer, previous, delta);
        });
    }
}
class EmscriptenDebug {
    constructor() {
        this.onAllocate = new debug_weak_broadcast_event_js_1.DebugWeakBroadcastEvent("debugOnAllocate");
        this.protectedViews = new debug_weak_value_js_1.DebugWeakValue();
        this.sharedObjectLifeCycleChecks = new debug_shared_object_life_cycle_checker_js_1.DebugSharedObjectLifeCycleChecker();
        this.uniquePointers = new Set();
    }
    error(message) {
        _debug_js_1._Debug.error(message);
    }
    verboseLog(message, tags = array_empty_array_js_1.arrayEmptyArray) {
        _debug_js_1._Debug.verboseLog(tags, message);
    }
}
//# sourceMappingURL=get-emscripten-wrapper.js.map