import { Emscripten } from "../../external/emscripten.js";
import { IEmscriptenWrapper } from "./i-emscripten-wrapper.js";
import { IDebugBindings } from "./i-debug-bindings.js";
/**
 * @public
 */
export interface ISanitizedTestModuleOptions {
    disabledErrors: Set<string>;
    /**
     * 64 kb per page
     */
    initialMemoryPages: number;
    /**
     * 64 kb per page
     */
    maxMemoryPages?: number;
    quitThrowsWith: object;
}
/**
 * @public
 */
export declare const emscriptenAsanTestModuleOptions: ISanitizedTestModuleOptions;
/**
 * @public
 */
export declare const emscriptenSafeHeapTestModuleOptions: ISanitizedTestModuleOptions;
/**
 * @public
 * A wrapper for running emscripten modules built with ASAN. To see the full report, you must call `endEmscriptenProgram`.
 * @typeParam TEmscriptenBindings - The generated WASM bindings.
 * @typeParam TWrapperExtensions - Extensions to the test wrapper itself, i.e. overwrite the module with test specific logic.
 */
export declare class SanitizedEmscriptenTestModule<TEmscriptenBindings extends object, TWrapperExtensions extends object> {
    private readonly testModule;
    private readonly options;
    private readonly extension?;
    constructor(testModule: Emscripten.EmscriptenModuleFactory<TEmscriptenBindings>, options: ISanitizedTestModuleOptions, extension?: TWrapperExtensions | undefined);
    initialize(): Promise<void>;
    get wrapper(): IEmscriptenWrapper<TEmscriptenBindings & TWrapperExtensions & IDebugBindings>;
    /**
     * NB you MUST set the flag `-s EXIT_RUNTIME=1` for this to work.
     */
    endEmscriptenProgram(): void;
    /**
     * Call this before each test case.
     */
    reset(): void;
    private _wrapper;
}
