"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SanitizedEmscriptenTestModule = exports.emscriptenSafeHeapTestModuleOptions = exports.emscriptenAsanTestModuleOptions = void 0;
const tslib_1 = require("tslib");
const get_wasm_test_memory_js_1 = require("../util/get-wasm-test-memory.js");
const get_emscripten_wrapper_js_1 = require("./get-emscripten-wrapper.js");
const _fp_js_1 = require("../../fp/_fp.js");
const _production_js_1 = require("../../production/_production.js");
const test_reset_life_cycle_js_1 = require("../../test-util/test_reset-life-cycle.js");
/**
 * @public
 */
exports.emscriptenAsanTestModuleOptions = {
    disabledErrors: new Set(["==42==WARNING: AddressSanitizer failed to allocate 0xfffffffc bytes"]),
    initialMemoryPages: 8192,
    maxMemoryPages: 8192,
    quitThrowsWith: {},
};
/**
 * @public
 */
exports.emscriptenSafeHeapTestModuleOptions = {
    disabledErrors: new Set(),
    initialMemoryPages: 128,
    maxMemoryPages: 512,
    quitThrowsWith: {},
};
/**
 * @public
 * A wrapper for running emscripten modules built with ASAN. To see the full report, you must call `endEmscriptenProgram`.
 * @typeParam TEmscriptenBindings - The generated WASM bindings.
 * @typeParam TWrapperExtensions - Extensions to the test wrapper itself, i.e. overwrite the module with test specific logic.
 */
class SanitizedEmscriptenTestModule {
    constructor(testModule, options, extension) {
        this.testModule = testModule;
        this.options = options;
        this.extension = extension;
    }
    initialize() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const memory = (0, get_wasm_test_memory_js_1.getWasmTestMemory)({ initial: this.options.initialMemoryPages, maximum: this.options.maxMemoryPages });
            this._wrapper = (yield (0, get_emscripten_wrapper_js_1.getEmscriptenWrapper)(memory, this.testModule, Object.assign({ ASAN_OPTIONS: "allocator_may_return_null=1", print: _fp_js_1._Fp.noOp, printErr: (error) => {
                    // looks like asan writes to stderr regardless of option...
                    if (this.options.disabledErrors.has(error)) {
                        return;
                    }
                    throw new Error(error);
                }, quit: () => {
                    // emscripten hits asserts if quit doesn't interrupt execution
                    // the default behavior in node is to kill the process which would kill the tests
                    // by throwing something unique we can catch but avoid swallowing actual errors
                    throw this.options.quitThrowsWith;
                } }, this.extension)));
        });
    }
    get wrapper() {
        if (this._wrapper == null) {
            throw _production_js_1._Production.createError("initialize must be called first");
        }
        return this._wrapper;
    }
    /**
     * NB you MUST set the flag `-s EXIT_RUNTIME=1` for this to work.
     */
    endEmscriptenProgram() {
        // kick off asan checks
        try {
            this.wrapper.instance._jsUtilEndProgram(0);
        }
        catch (error) {
            if (error !== exports.emscriptenAsanTestModuleOptions.quitThrowsWith) {
                throw error;
            }
        }
    }
    /**
     * Call this before each test case.
     */
    reset() {
        (0, test_reset_life_cycle_js_1.Test_resetLifeCycle)();
        if (this._wrapper) {
            this._wrapper.debug.uniquePointers.clear();
        }
    }
}
exports.SanitizedEmscriptenTestModule = SanitizedEmscriptenTestModule;
//# sourceMappingURL=sanitized-emscripten-test-module.js.map