import { TTypedArrayCtor } from "../../array/typed-array/t-typed-array-ctor.js";
import { IReferenceCountedPtr } from "../util/reference-counted-ptr.js";
import { IEmscriptenWrapper } from "../emscripten/i-emscripten-wrapper.js";
import { ISharedArray } from "./i-shared-array.js";
import { ISharedArrayBindings, TSharedArrayPrefix } from "./i-shared-array-bindings.js";
import { IOnMemoryResize } from "../emscripten/i-on-memory-resize.js";
import { IDebugAllocateListener } from "../../debug/i-debug-allocate-listener.js";
import { ILinkedReferences } from "../../lifecycle/linked-references.js";
/**
 * @public
 * Float32 {@link ISharedArray}.
 */
export type TF32SharedArray = ISharedArray<Float32ArrayConstructor>;
/**
 * @public
 * Float64 {@link ISharedArray}.
 */
export type TF64SharedArray = ISharedArray<Float64ArrayConstructor>;
/**
 * @public
 * Typed array shared between wasm and javascript.
 */
export declare class SharedArray<TCtor extends TTypedArrayCtor> implements ISharedArray<TCtor>, IOnMemoryResize, IDebugAllocateListener {
    /**
     * @throws exception if allocation cannot be performed.
     */
    static createOneF32(wrapper: IEmscriptenWrapper<ISharedArrayBindings>, bindToReference: ILinkedReferences | null, length: number, clearMemory?: boolean): TF32SharedArray;
    static createOneF32(wrapper: IEmscriptenWrapper<ISharedArrayBindings>, bindToReference: ILinkedReferences | null, length: number, clearMemory?: boolean, allocationFailThrows?: boolean): TF32SharedArray | null;
    /**
     * @throws exception if allocation cannot be performed.
     */
    static createOneF64(wrapper: IEmscriptenWrapper<ISharedArrayBindings>, bindToReference: ILinkedReferences | null, length: number, clearMemory?: boolean): TF64SharedArray;
    static createOneF64(wrapper: IEmscriptenWrapper<ISharedArrayBindings>, bindToReference: ILinkedReferences | null, length: number, clearMemory?: boolean, allocationFailThrows?: boolean): TF64SharedArray | null;
    private static createOne;
    private static allocateMemory;
    readonly ctor: TCtor;
    readonly length: number;
    readonly elementByteSize: number;
    readonly sharedObject: IReferenceCountedPtr;
    debugOnAllocate?: (() => void);
    getInstance(): InstanceType<TCtor>;
    onMemoryResize: () => void;
    protected constructor(cMethodPrefix: TSharedArrayPrefix, ctor: TCtor, wrapper: IEmscriptenWrapper<ISharedArrayBindings>, length: number, pointer: number);
    private createLocalInstance;
    private instance;
    private readonly wrapper;
    private readonly cGetArrayAddress;
    private readonly cDelete;
}
