import { TTypedArrayCtor } from "../../array/typed-array/t-typed-array-ctor.js";
import { IEmscriptenWrapper } from "../emscripten/i-emscripten-wrapper.js";
import { ISharedArray } from "./i-shared-array.js";
import { IReferenceCountedPtr } from "../util/reference-counted-ptr.js";
import { ISharedArrayBindings } from "./i-shared-array-bindings.js";
import { IOnMemoryResize } from "../emscripten/i-on-memory-resize.js";
import { IDebugAllocateListener } from "../../debug/i-debug-allocate-listener.js";
import { ILinkedReferences } from "../../lifecycle/linked-references.js";
/**
 * @public
 * Float32 {@link ISharedArray} (static).
 */
export type TF32SharedStaticArray = ISharedArray<Float32ArrayConstructor>;
/**
 * @public
 * Float64 {@link ISharedArray} (static).
 */
export type TF64SharedStaticArray = ISharedArray<Float64ArrayConstructor>;
/**
 * @public
 * Typed array representing static memory in wasm.
 */
export declare class SharedStaticArray<TCtor extends TTypedArrayCtor> implements ISharedArray<TCtor>, IOnMemoryResize, IDebugAllocateListener {
    static createOneF32(wrapper: IEmscriptenWrapper<ISharedArrayBindings>, bindToReference: ILinkedReferences | null, pointer: number, length: number): TF32SharedStaticArray;
    static createOneF64(wrapper: IEmscriptenWrapper<ISharedArrayBindings>, bindToReference: ILinkedReferences | null, pointer: number, length: number): TF64SharedStaticArray;
    readonly ctor: TCtor;
    readonly length: number;
    readonly elementByteSize: number;
    readonly sharedObject: IReferenceCountedPtr;
    debugOnAllocate?: (() => void);
    getInstance(): InstanceType<TCtor>;
    onMemoryResize: () => void;
    protected constructor(ctor: TCtor, wrapper: IEmscriptenWrapper<ISharedArrayBindings>, pointer: number, length: number);
    private createLocalInstance;
    private readonly wrapper;
    private instance;
}
