"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SharedStaticArray = void 0;
const _debug_js_1 = require("../../debug/_debug.js");
const debug_protected_view_js_1 = require("../../debug/debug-protected-view.js");
const reference_counted_ptr_js_1 = require("../util/reference-counted-ptr.js");
const debug_shared_object_checks_js_1 = require("../util/debug-shared-object-checks.js");
/**
 * @public
 * Typed array representing static memory in wasm.
 */
class SharedStaticArray {
    static createOneF32(wrapper, bindToReference, pointer, length) {
        const sta = new SharedStaticArray(Float32Array, wrapper, pointer, length);
        bindToReference === null || bindToReference === void 0 ? void 0 : bindToReference.linkRef(sta.sharedObject);
        return sta;
    }
    static createOneF64(wrapper, bindToReference, pointer, length) {
        const sta = new SharedStaticArray(Float64Array, wrapper, pointer, length);
        bindToReference === null || bindToReference === void 0 ? void 0 : bindToReference.linkRef(sta.sharedObject);
        return sta;
    }
    getInstance() {
        if (_BUILD.DEBUG) {
            _debug_js_1._Debug.assert(!this.sharedObject.getIsDestroyed(), "access violation - object has been destroyed");
            return this.wrapper.debug.protectedViews
                .getValue(this)
                .createProtectedView(this.instance);
        }
        else {
            return this.instance;
        }
    }
    constructor(ctor, wrapper, pointer, length) {
        this.onMemoryResize = () => {
            this.instance = this.createLocalInstance();
        };
        this.sharedObject = new reference_counted_ptr_js_1.ReferenceCountedPtr(true, pointer, wrapper);
        this.length = length;
        this.ctor = ctor;
        this.wrapper = wrapper;
        this.elementByteSize = ctor.BYTES_PER_ELEMENT;
        _BUILD.DEBUG && _debug_js_1._Debug.runBlock(() => {
            debug_shared_object_checks_js_1.DebugSharedObjectChecks.registerWithCleanup(this, debug_protected_view_js_1.DebugProtectedView.createTypedArrayView(this.wrapper), "");
        });
        this.sharedObject.registerOnFreeListener(wrapper.memoryResize.addTemporaryListener(this));
        this.instance = this.createLocalInstance();
    }
    createLocalInstance() {
        return new this.ctor(this.wrapper.memory.buffer, this.sharedObject.getPtr(), this.length);
    }
}
exports.SharedStaticArray = SharedStaticArray;
//# sourceMappingURL=shared-static-array.js.map