import { IReferenceCountedPtr } from "../util/reference-counted-ptr.js";
import { IEmscriptenWrapper } from "../emscripten/i-emscripten-wrapper.js";
import { IMemoryUtilBindings } from "../emscripten/i-memory-util-bindings.js";
import { ISharedObject } from "../../lifecycle/i-shared-object.js";
import { IOnMemoryResize } from "../emscripten/i-on-memory-resize.js";
import { IDebugAllocateListener } from "../../debug/i-debug-allocate-listener.js";
import { ILinkedReferences } from "../../lifecycle/linked-references.js";
/**
 * @public
 * Provides a reference counted wrapper to a pointer `malloc`'d from JS and is `free`'d on reference count hitting 0.
 */
export interface ISharedMemoryBlock extends ISharedObject, IOnMemoryResize {
    readonly pointer: number;
    readonly byteSize: number;
    getDataView(): DataView;
}
/**
 * @public
 * {@inheritDoc ISharedMemoryBlock}
 */
export declare class SharedMemoryBlock implements ISharedMemoryBlock, IDebugAllocateListener {
    private readonly wrapper;
    readonly sharedObject: IReferenceCountedPtr;
    readonly pointer: number;
    readonly byteSize: number;
    /**
     * @throws exception if allocation cannot be performed.
     */
    static createOne(wrapper: IEmscriptenWrapper<IMemoryUtilBindings>, bindToReference: ILinkedReferences | null, byteSize: number): SharedMemoryBlock;
    static createOne(wrapper: IEmscriptenWrapper<IMemoryUtilBindings>, bindToReference: ILinkedReferences | null, byteSize: number, allocationFailThrows: boolean): SharedMemoryBlock | null;
    getDataView(): DataView;
    onMemoryResize: () => void;
    protected constructor(wrapper: IEmscriptenWrapper<IMemoryUtilBindings>, pointer: number, byteSize: number);
    private recreateDataView;
    private dataView;
    debugOnAllocate?: (() => void);
}
