"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SharedMemoryBlock = void 0;
const reference_counted_ptr_js_1 = require("../util/reference-counted-ptr.js");
const null_pointer_js_1 = require("../emscripten/null-pointer.js");
const _production_js_1 = require("../../production/_production.js");
const debug_protected_view_js_1 = require("../../debug/debug-protected-view.js");
const _debug_js_1 = require("../../debug/_debug.js");
const debug_shared_object_checks_js_1 = require("../util/debug-shared-object-checks.js");
const _number_js_1 = require("../../number/_number.js");
/**
 * @public
 * {@inheritDoc ISharedMemoryBlock}
 */
class SharedMemoryBlock {
    static createOne(wrapper, bindToReference, byteSize, allocationFailThrows = true) {
        _BUILD.DEBUG && wrapper.debug.onAllocate.emit();
        const pointer = wrapper.instance._jsUtilMalloc(byteSize);
        if (pointer == null_pointer_js_1.nullPointer) {
            if (allocationFailThrows) {
                throw _production_js_1._Production.createError("Failed to allocate memory for shared memory block.");
            }
            else {
                return null;
            }
        }
        const smb = new SharedMemoryBlock(wrapper, pointer, byteSize);
        bindToReference === null || bindToReference === void 0 ? void 0 : bindToReference.linkRef(smb.sharedObject);
        return smb;
    }
    getDataView() {
        if (_BUILD.DEBUG) {
            return this.wrapper.debug.protectedViews
                .getValue(this)
                .createProtectedView(this.dataView);
        }
        else {
            return this.dataView;
        }
    }
    constructor(wrapper, pointer, byteSize) {
        this.wrapper = wrapper;
        this.onMemoryResize = () => {
            if (this.wrapper == null) {
                _BUILD.DEBUG && _debug_js_1._Debug.error("object has been destroyed");
                return;
            }
            this.dataView = this.recreateDataView();
        };
        this.pointer = pointer;
        this.byteSize = byteSize;
        this.sharedObject = new reference_counted_ptr_js_1.ReferenceCountedPtr(false, pointer, wrapper);
        this.sharedObject.registerOnFreeListener(this.wrapper.memoryResize.addTemporaryListener(this));
        this.sharedObject.registerOnFreeListener(() => this.wrapper.instance._jsUtilFree(this.pointer));
        _BUILD.DEBUG && _debug_js_1._Debug.runBlock(() => {
            const protectedView = new debug_protected_view_js_1.DebugProtectedView(this.wrapper, `SharedMemoryBlock - memory resize danger: don't hold reference to the DataView ${_number_js_1._Number.getHexString(this.pointer)}`);
            debug_shared_object_checks_js_1.DebugSharedObjectChecks.registerWithCleanup(this, protectedView, "SharedMemoryBlock");
        });
        this.dataView = this.recreateDataView();
    }
    recreateDataView() {
        return new DataView(this.wrapper.memory.buffer, this.pointer, this.byteSize);
    }
}
exports.SharedMemoryBlock = SharedMemoryBlock;
//# sourceMappingURL=shared-memory-block.js.map