"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReferenceCountedPtr = void 0;
const a_reference_counted_js_1 = require("../../lifecycle/a-reference-counted.js");
const _debug_js_1 = require("../../debug/_debug.js");
const null_pointer_js_1 = require("../emscripten/null-pointer.js");
const lifecycle_stack_js_1 = require("../emscripten/lifecycle-stack.js");
/**
 * @public
 * Wrapper of wasm object.
 */
class ReferenceCountedPtr extends a_reference_counted_js_1.AReferenceCounted {
    static createOneBound(bindToReference, isStatic, wasmPtr, wrapper) {
        const ptr = new ReferenceCountedPtr(isStatic, wasmPtr, wrapper);
        bindToReference === null || bindToReference === void 0 ? void 0 : bindToReference.linkRef(ptr);
        return ptr;
    }
    getPtr() {
        return this.wasmPtr;
    }
    /**
     * DO NOT CALL THIS DIRECTLY, CALL RELEASE.
     */
    onFree() {
        _BUILD.DEBUG && _debug_js_1._Debug.runBlock(() => {
            this.wrapper.debug.uniquePointers.delete(this.wasmPtr);
        });
        super.onFree();
        this.wasmPtr = null_pointer_js_1.nullPointer;
    }
    constructor(isStatic, wasmPtr, wrapper) {
        super();
        this.isStatic = isStatic;
        this.wasmPtr = wasmPtr;
        this.wrapper = wrapper;
        lifecycle_stack_js_1.lifecycleStack.register(this);
        _BUILD.DEBUG && _debug_js_1._Debug.runBlock(() => {
            _debug_js_1._Debug.assert(this.wasmPtr !== null_pointer_js_1.nullPointer && this.wasmPtr != null, "expected pointer to object but got null pointer");
            if (!this.isStatic) {
                _debug_js_1._Debug.assert(!this.wrapper.debug.uniquePointers.has(this.wasmPtr), "expected pointer to be unique");
                this.wrapper.debug.uniquePointers.add(this.wasmPtr);
            }
        });
    }
}
exports.ReferenceCountedPtr = ReferenceCountedPtr;
//# sourceMappingURL=reference-counted-ptr.js.map