import { getMat2Ctor } from "../../mat2/get-mat2-ctor.js";
import { Vec2 } from "../../vec2/vec2.js";
import { Mat2Factory } from "../../mat2/mat2-factory.js";
import { NormalizedDataViewProvider } from "../../normalized-data-view/normalized-data-view-provider.js";
import { _Debug } from "../../../../debug/_debug.js";
import { Mat3 } from "../../mat3/mat3.js";
/**
 * @internal
 */
export function getRange2dCtor(ctor) {
    var _a;
    return _a = class Range2dImpl extends getMat2Ctor(ctor) {
            setXMin(value) {
                this[0] = value;
            }
            setXMax(value) {
                this[1] = value;
            }
            setYMin(value) {
                this[2] = value;
            }
            setYMax(value) {
                this[3] = value;
            }
            getXMin() {
                return this[0];
            }
            getXMax() {
                return this[1];
            }
            getYMin() {
                return this[2];
            }
            getYMax() {
                return this[3];
            }
            getRange(result = this.constructor.vec2Ctor.factory.createOneEmpty()) {
                result.setX(this.getXRange());
                result.setY(this.getYRange());
                return result;
            }
            getXRange() {
                return this[1] - this[0];
            }
            getYRange() {
                return this[3] - this[2];
            }
            getXMaxAbs() {
                const xMinAbs = Math.abs(this.getXMin());
                const xMaxAbs = Math.abs(this.getXMax());
                return xMinAbs > xMaxAbs ? xMinAbs : xMaxAbs;
            }
            getYMaxAbs() {
                const yMinAbs = Math.abs(this.getYMin());
                const yMaxAbs = Math.abs(this.getYMax());
                return yMinAbs > yMaxAbs ? yMinAbs : yMaxAbs;
            }
            getCenter(result = this.constructor.vec2Ctor.factory.createOneEmpty()) {
                result.setX(this.getXCenter());
                result.setY(this.getYCenter());
                return result;
            }
            getXCenter() {
                return (this[0] + this[1]) * 0.5;
            }
            getYCenter() {
                return (this[2] + this[3]) * 0.5;
            }
            mat3Multiply(mat, writeTo = this.constructor.factory.createOneEmpty()) {
                writeTo.setXMin(mat.getVec3MultiplyX(this.getXMin()));
                writeTo.setXMax(mat.getVec3MultiplyX(this.getXMax()));
                writeTo.setYMin(mat.getVec3MultiplyY(this.getYMin()));
                writeTo.setYMax(mat.getVec3MultiplyY(this.getYMax()));
                return writeTo;
            }
            unionRange(range, writeTo = this.constructor.factory.createOneEmpty()) {
                writeTo[0] = this[0] > range[0] ? range[0] : this[0];
                writeTo[1] = this[1] < range[1] ? range[1] : this[1];
                writeTo[2] = this[2] > range[2] ? range[2] : this[2];
                writeTo[3] = this[3] < range[3] ? range[3] : this[3];
                return writeTo;
            }
            extendRange(x, y, writeTo = this.constructor.factory.createOneEmpty()) {
                writeTo[0] = this[0] > x ? x : this[0];
                writeTo[1] = this[1] < x ? x : this[1];
                writeTo[2] = this[2] > y ? y : this[2];
                writeTo[3] = this[3] < y ? y : this[3];
                return writeTo;
            }
            getRangeTransform(toRange, result = this.constructor.mat3Ctor.factory.createOneEmpty()) {
                _BUILD.DEBUG && _Debug.runBlock(() => {
                    _Debug.assert(this.getXRange() !== 0, "divide by 0");
                    _Debug.assert(this.getYRange() !== 0, "divide by 0");
                });
                const xSf = toRange.getXRange() / this.getXRange();
                const ySf = toRange.getYRange() / this.getYRange();
                result[0] = xSf;
                result[1] = 0;
                result[2] = 0;
                result[3] = 0;
                result[4] = ySf;
                result[5] = 0;
                result[6] = toRange.getXMin() - this.getXMin() * xSf;
                result[7] = toRange.getYMin() - this.getYMin() * ySf;
                result[8] = 1;
                return result;
            }
            isPointInRange(point) {
                const x = point.getX();
                const y = point.getY();
                return x >= this.getXMin() && x <= this.getXMax() && y >= this.getYMin() && y <= this.getYMax();
            }
            doesRangeIntersect(range) {
                return (Math.abs((this[0] + this[1]) - (range[0] + range[1])) < (this.getXRange() + range.getXRange()))
                    && (Math.abs(((this[2] + this[3])) - (range[2] + range[3])) < (this.getYRange() + range.getYRange()));
            }
            containsRange(range) {
                return this.getXMin() <= range.getXMin()
                    && this.getXMax() >= range.getXMax()
                    && this.getYMin() <= range.getYMin()
                    && this.getYMax() >= range.getYMax();
            }
            scaleRelativeTo(scalingFactor, relativeTo, result = this.constructor.factory.createOneEmpty()) {
                _BUILD.DEBUG && _Debug.assert(this.isPointInRange(relativeTo), "relativeTo must be inside the range");
                const difference = this
                    .getCenter(this.constructor.tmpVec)
                    .subtract(relativeTo, this.constructor.tmpVec);
                // multiply by 2 as we want to compare to half the range
                // make the difference relative, varies from -1 to 1
                difference.setX(2 * difference.getX() / this.getXRange());
                difference.setY(2 * difference.getY() / this.getYRange());
                const newXRange = this.getXRange() * scalingFactor;
                const newYRange = this.getYRange() * scalingFactor;
                const halfXDiff = 0.5 * (this.getXRange() - newXRange);
                const halfYDiff = 0.5 * (this.getYRange() - newYRange);
                const newXMin = this.getXMin() + halfXDiff - halfXDiff * difference.getX();
                result.setXMin(newXMin);
                result.setXMax(newXMin + newXRange);
                const newYMin = this.getYMin() + halfYDiff - halfYDiff * difference.getY();
                result.setYMin(newYMin);
                result.setYMax(newYMin + newYRange);
                return result;
            }
            bound(boundTo) {
                if (this.getXRange() > boundTo.getXRange()) {
                    this.setXMin(boundTo.getXMin());
                    this.setXMax(boundTo.getXMax());
                }
                else if (this.getXMax() > boundTo.getXMax()) {
                    const range = this.getXRange();
                    this.setXMax(boundTo.getXMax());
                    this.setXMin(boundTo.getXMax() - range);
                }
                else if (this.getXMin() < boundTo.getXMin()) {
                    const range = this.getXRange();
                    this.setXMin(boundTo.getXMin());
                    this.setXMax(boundTo.getXMin() + range);
                }
                if (this.getYRange() > boundTo.getYRange()) {
                    this.setYMin(boundTo.getYMin());
                    this.setYMax(boundTo.getYMax());
                }
                else if (this.getYMax() > boundTo.getYMax()) {
                    const range = this.getYRange();
                    this.setYMax(boundTo.getYMax());
                    this.setYMin(boundTo.getYMax() - range);
                }
                else if (this.getYMin() < boundTo.getYMin()) {
                    const range = this.getYRange();
                    this.setYMin(boundTo.getYMin());
                    this.setYMax(boundTo.getYMin() + range);
                }
            }
            ensureAABB() {
                if (this[0] > this[1]) {
                    const tmp = this[0];
                    this[0] = this[1];
                    this[1] = tmp;
                }
                if (this[2] > this[3]) {
                    const tmp = this[2];
                    this[2] = this[3];
                    this[3] = tmp;
                }
            }
            ensureMinRange(xMinRange, yMinRange) {
                const xRange = this.getXRange();
                if (xRange < xMinRange) {
                    const diff = (xMinRange - xRange) * 0.5;
                    this.setXMin(this.getXMin() - diff);
                    this.setXMax(this.getXMax() + diff);
                }
                const yRange = this.getYRange();
                if (yRange < yMinRange) {
                    const diff = (yMinRange - yRange) * 0.5;
                    this.setYMin(this.getYMin() - diff);
                    this.setYMax(this.getYMax() + diff);
                }
            }
            translateBy(dx, dy) {
                this.setXMin(this.getXMin() + dx);
                this.setXMax(this.getXMax() + dx);
                this.setYMin(this.getYMin() + dy);
                this.setYMax(this.getYMax() + dy);
            }
        },
        _a.factory = new Mat2Factory(_a, NormalizedDataViewProvider.getView(ctor)),
        _a.vec2Ctor = Vec2.getCtor(ctor),
        _a.mat3Ctor = Mat3.getCtor(ctor),
        _a.tmpVec = _a.vec2Ctor.factory.createOneEmpty(),
        _a;
}
//# sourceMappingURL=get-range2d-ctor.js.map