import { Mat2 } from "../../mat2/mat2.js";
import { getRange2dCtor } from "./get-range2d-ctor.js";
import { populateTypedArrayConstructorMap } from "../../populate-typed-array-constructor-map.js";
/**
 * @public
 * 2x2 matrix representing a 2d range.
 *
 * @remarks
 * See static properties for constructors. Instances are not an extension of this class, but of the static members.
 */
export class Range2d extends Mat2 {
    static getCtor(ctor) {
        return Range2d.constructors.get(ctor);
    }
    setXMin(_value) {
        throw new Error();
    }
    setXMax(_value) {
        throw new Error();
    }
    setYMin(_value) {
        throw new Error();
    }
    setYMax(_value) {
        throw new Error();
    }
    getXMin() {
        throw new Error();
    }
    getXMax() {
        throw new Error();
    }
    getYMin() {
        throw new Error();
    }
    getYMax() {
        throw new Error();
    }
    update(..._args) {
        throw new Error();
    }
    getRange(_result) {
        throw new Error();
    }
    getXRange() {
        throw new Error();
    }
    getYRange() {
        throw new Error();
    }
    getXMaxAbs() {
        throw new Error();
    }
    getYMaxAbs() {
        throw new Error();
    }
    getCenter(_result) {
        throw new Error();
    }
    getXCenter() {
        throw new Error();
    }
    getYCenter() {
        throw new Error();
    }
    mat3Multiply(_mat, _writeTo) {
        throw new Error();
    }
    unionRange(_range, _writeTo) {
        throw new Error();
    }
    extendRange(_x, _y, _writeTo) {
        throw new Error();
    }
    /**
     * Creates a transform matrix that maps values in this range onto `_toRange`.
     */
    getRangeTransform(_toRange, _result) {
        throw new Error();
    }
    isPointInRange(_point) {
        throw new Error();
    }
    doesRangeIntersect(_range) {
        throw new Error();
    }
    containsRange(_range) {
        throw new Error();
    }
    /* eslint-disable no-irregular-whitespace */
    /**
     * Scales the range relative to a point (may not be outside of the range).
     *
     * @remarks
     * If the point is at a boundary, then the range will be scaled such that that boundary is not changed. Where the
     * point is away from a boundary, the updated range will have boundaries proportional to the distance from the center
     * of the range.
     *
     * E.g. scaling factor of 0.5, P represents the position of the point in the range:
     *```
     * XMin                      XMax
     *  |P-------------------------|
     *  |-------------|
     *
     *  |------------P-------------|
     *        |-------------|
     *```
     */
    /* eslint-enable no-irregular-whitespace */
    scaleRelativeTo(_scalingFactor, _relativeTo, _result) {
        throw new Error();
    }
    /**
     * Bound this range to the argument.
     *
     * @remarks
     * Where this range is larger than the bounding range, it will be resized to fit.
     * Where this range is smaller than the bounding range but not contained, it will be moved maintaining its size. It
     * Will be moved such that the the side furthest from the bounding range will be at the edge of the boundary.
     */
    bound(_boundTo) {
        throw new Error();
    }
    ensureAABB() {
        throw new Error();
    }
    /**
     * Bound this range to be at least as large as the argument.
     *
     * @remarks
     * Where this range is smaller than the bounding range, it will be resized to be the minimum. This is done by adding
     * equally to both the min and max.
     */
    ensureMinRange(_xMinRange, _yMinRange) {
        throw new Error();
    }
    /**
     * Shifts the range by (dx, dy).
     */
    translateBy(_dx, _dy) {
        throw new Error();
    }
    /**
     * If endianness is not supplied the platform's endianness will be used.
     */
    copyFromBuffer(_memoryDataView, _pointer, _littleEndian) {
        throw new Error();
    }
    /**
     * If endianness is not supplied the platform's endianness will be used.
     */
    copyToBuffer(_memoryDataView, _pointer, _littleEndian) {
        throw new Error();
    }
    /**
     * Although the typed array tuples extend a typed array, they are not structurally compatible.
     * This function returns the argument passed without modification but cast as the underlying storage type, e.g. Float32Array.
     */
    castToBaseType() {
        throw new Error();
    }
}
Range2d.f64 = getRange2dCtor(Float64Array);
Range2d.f32 = getRange2dCtor(Float32Array);
Range2d.u32 = getRange2dCtor(Uint32Array);
Range2d.i32 = getRange2dCtor(Int32Array);
Range2d.u16 = getRange2dCtor(Uint16Array);
Range2d.i16 = getRange2dCtor(Int16Array);
Range2d.u8c = getRange2dCtor(Uint8ClampedArray);
Range2d.u8 = getRange2dCtor(Uint8Array);
Range2d.i8 = getRange2dCtor(Int8Array);
Range2d.constructors = populateTypedArrayConstructorMap(Range2d);
//# sourceMappingURL=range2d.js.map