import { Mat3Factory } from "./mat3-factory.js";
import { _Debug } from "../../../debug/_debug.js";
import { NormalizedDataViewProvider } from "../normalized-data-view/normalized-data-view-provider.js";
import { Vec3 } from "../vec3/vec3.js";
/**
 * @internal
 */
export function getMat3Ctor(ctor) {
    var _a;
    return _a = class Mat3Impl extends ctor {
            constructor(bufferOrLength = 9, offset, length) {
                super(bufferOrLength, offset, length);
            }
            isEqualTo(other) {
                let isEqual = true;
                for (let i = 0; i < 9 && isEqual; ++i) {
                    isEqual && (isEqual = this[i] === other[i]);
                }
                return isEqual;
            }
            setIdentityMatrix() {
                this.fill(0);
                this[0] = 1;
                this[4] = 1;
                this[8] = 1;
                return this;
            }
            getValueAt(column, row) {
                _BUILD.DEBUG && _Debug.assert(column >= 0 && column < 3 && row >= 0 && row < 3, "out of bounds");
                return this[row * 3 + column];
            }
            setValueAt(column, row, value) {
                _BUILD.DEBUG && _Debug.assert(column >= 0 && column < 3 && row >= 0 && row < 3, "out of bounds");
                this[row * 3 + column] = value;
            }
            getRow(row, writeTo = this.constructor.vec3Ctor.factory.createOneEmpty()) {
                _BUILD.DEBUG && _Debug.assert(row >= 0 && row < 3, "index out of bounds");
                writeTo[0] = this.getValueAt(0, row);
                writeTo[1] = this.getValueAt(1, row);
                writeTo[2] = this.getValueAt(2, row);
                return writeTo;
            }
            setRow(row, writeFrom) {
                _BUILD.DEBUG && _Debug.assert(row >= 0 && row < 3, "index out of bounds");
                this.setValueAt(0, row, writeFrom[0]);
                this.setValueAt(1, row, writeFrom[1]);
                this.setValueAt(2, row, writeFrom[2]);
            }
            setRotationMatrix(angle) {
                const sine = Math.sin(angle);
                const cosine = Math.cos(angle);
                this[0] = cosine;
                this[1] = -sine;
                this[2] = 0;
                this[3] = sine;
                this[4] = cosine;
                this[5] = 0;
                this[6] = 0;
                this[7] = 0;
                this[8] = 1;
                return this;
            }
            setScalingMatrix(scalingFactorX, scalingFactorY) {
                this[0] = scalingFactorX;
                this[1] = 0;
                this[2] = 0;
                this[3] = 0;
                this[4] = scalingFactorY;
                this[5] = 0;
                this[6] = 0;
                this[7] = 0;
                this[8] = 1;
                return this;
            }
            setTranslationMatrix(translationX, translationY) {
                this[0] = 1;
                this[1] = 0;
                this[2] = 0;
                this[3] = 0;
                this[4] = 1;
                this[5] = 0;
                this[6] = translationX;
                this[7] = translationY;
                this[8] = 1;
                return this;
            }
            scalarMultiply(value, result = this.constructor.factory.createOneEmpty()) {
                result[0] = this[0] * value;
                result[1] = this[1] * value;
                result[2] = this[2] * value;
                result[3] = this[3] * value;
                result[4] = this[4] * value;
                result[5] = this[5] * value;
                result[6] = this[6] * value;
                result[7] = this[7] * value;
                result[8] = this[8] * value;
                return result;
            }
            scalarAdd(value, result = this.constructor.factory.createOneEmpty()) {
                result[0] = this[0] + value;
                result[1] = this[1] + value;
                result[2] = this[2] + value;
                result[3] = this[3] + value;
                result[4] = this[4] + value;
                result[5] = this[5] + value;
                result[6] = this[6] + value;
                result[7] = this[7] + value;
                result[8] = this[8] + value;
                return result;
            }
            multiplyMat3(mat, result = this.constructor.factory.createOneEmpty()) {
                const [a0, a1, a2, a3, a4, a5, a6, a7, a8] = this;
                const [b0, b1, b2, b3, b4, b5, b6, b7, b8] = mat;
                result[0] = a0 * b0 + a1 * b3 + a2 * b6;
                result[1] = a0 * b1 + a1 * b4 + a2 * b7;
                result[2] = a0 * b2 + a1 * b5 + a2 * b8;
                result[3] = a3 * b0 + a4 * b3 + a5 * b6;
                result[4] = a3 * b1 + a4 * b4 + a5 * b7;
                result[5] = a3 * b2 + a4 * b5 + a5 * b8;
                result[6] = a6 * b0 + a7 * b3 + a8 * b6;
                result[7] = a6 * b1 + a7 * b4 + a8 * b7;
                result[8] = a6 * b2 + a7 * b5 + a8 * b8;
                return result;
            }
            getVec3MultiplyX(x) {
                return this[0] * x + this[3] * x + this[6];
            }
            getVec3MultiplyY(y) {
                return this[1] * y + this[4] * y + this[7];
            }
            getTransformedXLength(min, max) {
                return this.getVec3MultiplyX(max) - this.getVec3MultiplyX(min);
            }
            getTransformedYLength(min, max) {
                return this.getVec3MultiplyY(max) - this.getVec3MultiplyY(min);
            }
            getLoggableValue() {
                return [
                    [this[0], this[1], this[2]],
                    [this[3], this[4], this[5]],
                    [this[6], this[7], this[8]],
                ];
            }
            copyFromBuffer(memoryDataView, pointer, littleEndian) {
                this.constructor.factory.copyFromBuffer(memoryDataView, pointer, this, littleEndian);
            }
            copyToBuffer(memoryDataView, pointer, littleEndian) {
                this.constructor.factory.copyToBuffer(memoryDataView, this, pointer, littleEndian);
            }
            castToBaseType() {
                return this;
            }
        },
        _a.factory = new Mat3Factory(_a, NormalizedDataViewProvider.getView(ctor)),
        _a.vec3Ctor = Vec3.getCtor(ctor),
        _a;
}
//# sourceMappingURL=get-mat3-ctor.js.map