import { Mat4Factory } from "./mat4-factory.js";
import { _Debug } from "../../../debug/_debug.js";
import { NormalizedDataViewProvider } from "../normalized-data-view/normalized-data-view-provider.js";
import { Vec4 } from "../vec4/vec4.js";
/**
 * @internal
 */
export function getMat4Ctor(ctor) {
    var _a;
    return _a = class Mat4Impl extends ctor {
            constructor(bufferOrLength = 16, offset, length) {
                super(bufferOrLength, offset, length);
            }
            isEqualTo(other) {
                let isEqual = true;
                for (let i = 0; i < 16 && isEqual; ++i) {
                    isEqual && (isEqual = this[i] === other[i]);
                }
                return isEqual;
            }
            setIdentityMatrix() {
                this.fill(0);
                this[0] = 1;
                this[5] = 1;
                this[10] = 1;
                this[15] = 1;
                return this;
            }
            getValueAt(column, row) {
                _BUILD.DEBUG && _Debug.assert(column >= 0 && column < 4 && row >= 0 && row < 4, "out of bounds");
                return this[row * 4 + column];
            }
            setValueAt(column, row, value) {
                _BUILD.DEBUG && _Debug.assert(column >= 0 && column < 4 && row >= 0 && row < 4, "out of bounds");
                this[row * 4 + column] = value;
            }
            getRow(row, writeTo = this.constructor.vec4Ctor.factory.createOneEmpty()) {
                _BUILD.DEBUG && _Debug.assert(row >= 0 && row < 4, "index out of bounds");
                writeTo[0] = this.getValueAt(0, row);
                writeTo[1] = this.getValueAt(1, row);
                writeTo[2] = this.getValueAt(2, row);
                writeTo[3] = this.getValueAt(3, row);
                return writeTo;
            }
            setRow(row, writeFrom) {
                _BUILD.DEBUG && _Debug.assert(row >= 0 && row < 4, "index out of bounds");
                this.setValueAt(0, row, writeFrom[0]);
                this.setValueAt(1, row, writeFrom[1]);
                this.setValueAt(2, row, writeFrom[2]);
                this.setValueAt(3, row, writeFrom[3]);
            }
            getLoggableValue() {
                return [
                    [this[0], this[1], this[2], this[3]],
                    [this[4], this[5], this[6], this[7]],
                    [this[8], this[9], this[10], this[11]],
                    [this[12], this[13], this[14], this[15]],
                ];
            }
            copyFromBuffer(memoryDataView, pointer, littleEndian) {
                this.constructor.factory.copyFromBuffer(memoryDataView, pointer, this, littleEndian);
            }
            copyToBuffer(memoryDataView, pointer, littleEndian) {
                this.constructor.factory.copyToBuffer(memoryDataView, this, pointer, littleEndian);
            }
            castToBaseType() {
                return this;
            }
        },
        _a.factory = new Mat4Factory(_a, NormalizedDataViewProvider.getView(ctor)),
        _a.vec4Ctor = Vec4.getCtor(ctor),
        _a;
}
//# sourceMappingURL=get-mat4-ctor.js.map