import { ATypedArrayTuple } from "../a-typed-array-tuple.js";
import { getMat4Ctor } from "./get-mat4-ctor.js";
import { populateTypedArrayConstructorMap } from "../populate-typed-array-constructor-map.js";
/**
 * @public
 * Row major 4x4 matrix.
 *
 * @remarks
 * See static properties for constructors. Instances are not an extension of this class, but of the static members.
 */
export class Mat4 extends ATypedArrayTuple {
    static getCtor(ctor) {
        return Mat4.constructors.get(ctor);
    }
    /**
     * Component-wise equals.
     */
    isEqualTo(_other) {
        throw new Error();
    }
    setIdentityMatrix() {
        throw new Error();
    }
    getValueAt(_column, _row) {
        throw new Error();
    }
    setValueAt(_column, _row, _value) {
        throw new Error();
    }
    getRow(_row, _writeTo) {
        throw new Error();
    }
    setRow(_row, _writeFrom) {
        throw new Error();
    }
    getLoggableValue() {
        throw new Error();
    }
    /**
     * If endianness is not supplied the platform's endianness will be used.
     */
    copyFromBuffer(_memoryDataView, _pointer, _littleEndian) {
        throw new Error();
    }
    /**
     * If endianness is not supplied the platform's endianness will be used.
     */
    copyToBuffer(_memoryDataView, _pointer, _littleEndian) {
        throw new Error();
    }
    /**
     * Although the typed array tuples extend a typed array, they are not structurally compatible.
     * This function returns the argument passed without modification but cast as the underlying storage type, e.g. Float32Array.
     */
    castToBaseType() {
        throw new Error();
    }
}
Mat4.f64 = getMat4Ctor(Float64Array);
Mat4.f32 = getMat4Ctor(Float32Array);
Mat4.u32 = getMat4Ctor(Uint32Array);
Mat4.i32 = getMat4Ctor(Int32Array);
Mat4.u16 = getMat4Ctor(Uint16Array);
Mat4.i16 = getMat4Ctor(Int16Array);
Mat4.u8c = getMat4Ctor(Uint8ClampedArray);
Mat4.u8 = getMat4Ctor(Uint8Array);
Mat4.i8 = getMat4Ctor(Int8Array);
Mat4.constructors = populateTypedArrayConstructorMap(Mat4);
//# sourceMappingURL=mat4.js.map