import { Vec2Factory } from "./vec2-factory.js";
import { NormalizedDataViewProvider } from "../normalized-data-view/normalized-data-view-provider.js";
/**
 * @internal
 */
export function getVec2Ctor(ctor) {
    var _a;
    return _a = class Vec2Impl extends ctor {
            constructor(bufferOrLength = 2, offset, length) {
                super(bufferOrLength, offset, length);
            }
            isEqualTo(other) {
                return this[0] === other[0] && this[1] === other[1];
            }
            getX() {
                return this[0];
            }
            getY() {
                return this[1];
            }
            getMagnitude() {
                const x = this[0];
                const y = this[1];
                return Math.sqrt(x * x + y * y);
            }
            getMagnitudeSquared() {
                const x = this[0];
                const y = this[1];
                return x * x + y * y;
            }
            update(x, y) {
                this[0] = x;
                this[1] = y;
            }
            setX(x) {
                this[0] = x;
            }
            setY(y) {
                this[1] = y;
            }
            add(vec, result = this.constructor.factory.createOneEmpty()) {
                result[0] = this[0] + vec[0];
                result[1] = this[1] + vec[1];
                return result;
            }
            subtract(vec, result = this.constructor.factory.createOneEmpty()) {
                result[0] = this[0] - vec[0];
                result[1] = this[1] - vec[1];
                return result;
            }
            vec2Multiply(value, result = this.constructor.factory.createOneEmpty()) {
                result[0] = this[0] * value[0];
                result[1] = this[1] * value[1];
                return result;
            }
            scalarMultiply(value, result = this.constructor.factory.createOneEmpty()) {
                result[0] = this[0] * value;
                result[1] = this[1] * value;
                return result;
            }
            vec2Divide(value, result = this.constructor.factory.createOneEmpty()) {
                result[0] = this[0] / value[0];
                result[1] = this[1] / value[1];
                return result;
            }
            scalarDivide(value, result = this.constructor.factory.createOneEmpty()) {
                result[0] = this[0] / value;
                result[1] = this[1] / value;
                return result;
            }
            normalize(result = this.constructor.factory.createOneEmpty()) {
                const magnitude = this.getMagnitude();
                this.scalarDivide(magnitude, result);
                return result;
            }
            getNormal(result = this.constructor.factory.createOneEmpty()) {
                result[0] = this[1];
                result[1] = -this[0];
                return result;
            }
            dotProduct(vec) {
                return this[0] * vec[0] + this[1] * vec[1];
            }
            mat3Multiply(mat, result = this.constructor.factory.createOneEmpty()) {
                result[0] = mat[0] * this[0] + mat[3] * this[0] + mat[6];
                result[1] = mat[1] * this[1] + mat[4] * this[1] + mat[7];
                return result;
            }
            bound2d(range) {
                if (this[0] < range.getXMin()) {
                    this[0] = range.getXMin();
                }
                else if (this[0] > range.getXMax()) {
                    this[0] = range.getXMax();
                }
                if (this[1] < range.getYMin()) {
                    this[1] = range.getYMin();
                }
                else if (this[1] > range.getYMax()) {
                    this[1] = range.getYMax();
                }
            }
            translate2d(dx, dy) {
                this[0] += dx;
                this[1] += dy;
            }
            getLoggableValue() {
                return [
                    [this[0], this[1]],
                ];
            }
            copyFromBuffer(memoryDataView, pointer, littleEndian) {
                this.constructor.factory.copyFromBuffer(memoryDataView, pointer, this, littleEndian);
            }
            copyToBuffer(memoryDataView, pointer, littleEndian) {
                this.constructor.factory.copyToBuffer(memoryDataView, this, pointer, littleEndian);
            }
            castToBaseType() {
                return this;
            }
        },
        _a.factory = new Vec2Factory(_a, NormalizedDataViewProvider.getView(ctor)),
        _a;
}
//# sourceMappingURL=get-vec2-ctor.js.map