import { Vec4Factory } from "./vec4-factory.js";
import { NormalizedDataViewProvider } from "../normalized-data-view/normalized-data-view-provider.js";
import { RgbaColorPacker } from "../../../colors/rgba-color-packer.js";
/**
 * @internal
 */
export function getVec4Ctor(ctor) {
    var _a;
    return _a = class Vec4Impl extends ctor {
            constructor(bufferOrLength = 4, offset, length) {
                super(bufferOrLength, offset, length);
            }
            isEqualTo(other) {
                return this[0] === other[0] && this[1] === other[1] && this[2] === other[2] && this[3] === other[3];
            }
            setRGBAColor(packedRGBA, normalize = false) {
                if (normalize) {
                    // 1 / 255
                    this[0] = RgbaColorPacker.unpackR(packedRGBA) * 0.00392156862745098;
                    this[1] = RgbaColorPacker.unpackG(packedRGBA) * 0.00392156862745098;
                    this[2] = RgbaColorPacker.unpackB(packedRGBA) * 0.00392156862745098;
                    this[3] = RgbaColorPacker.unpackA(packedRGBA) * 0.00392156862745098;
                }
                else {
                    this[0] = RgbaColorPacker.unpackR(packedRGBA);
                    this[1] = RgbaColorPacker.unpackG(packedRGBA);
                    this[2] = RgbaColorPacker.unpackB(packedRGBA);
                    this[3] = RgbaColorPacker.unpackA(packedRGBA);
                }
                return this;
            }
            /**
             * @param normalized - Is the data normalized (i.e. ranges from 0 - 1)? If so it will be multiplied up by 255.
             */
            getPackedRGBAColor(normalized = false) {
                if (normalized) {
                    return RgbaColorPacker.packColor(this[0] * 255, this[1] * 255, this[2] * 255, this[3] * 255);
                }
                else {
                    return RgbaColorPacker.packColor(this[0], this[1], this[2], this[3]);
                }
            }
            getX() {
                return this[0];
            }
            getY() {
                return this[1];
            }
            getZ() {
                return this[2];
            }
            getW() {
                return this[3];
            }
            update(x, y, z, w) {
                this[0] = x;
                this[1] = y;
                this[2] = z;
                this[3] = w;
            }
            setX(x) {
                this[0] = x;
            }
            setY(y) {
                this[1] = y;
            }
            setZ(z) {
                this[2] = z;
            }
            setW(w) {
                this[3] = w;
            }
            getLoggableValue() {
                return [
                    [this[0], this[1], this[2]],
                ];
            }
            copyFromBuffer(memoryDataView, pointer, littleEndian) {
                this.constructor.factory.copyFromBuffer(memoryDataView, pointer, this, littleEndian);
            }
            copyToBuffer(memoryDataView, pointer, littleEndian) {
                this.constructor.factory.copyToBuffer(memoryDataView, this, pointer, littleEndian);
            }
            castToBaseType() {
                return this;
            }
        },
        _a.factory = new Vec4Factory(_a, NormalizedDataViewProvider.getView(ctor)),
        _a.elementCount = 4,
        _a;
}
//# sourceMappingURL=get-vec4-ctor.js.map