/**
 * @public
 * {@inheritDoc IDirtyCheckedUniqueCollection}
 */
export class DirtyCheckedUniqueCollection {
    get size() {
        return this.itemsSet.size;
    }
    static mapInitializeAdd(map, key, value) {
        const collection = map.get(key);
        if (collection == null) {
            const collection = new DirtyCheckedUniqueCollection();
            collection.add(value);
            map.set(key, collection);
            return true;
        }
        else {
            return collection.reportingAdd(value);
        }
    }
    constructor(itemsToCopy) {
        this.isDirty = true;
        this.itemsArray = [];
        this.itemsSet = new Set(itemsToCopy);
    }
    add(item) {
        this.itemsSet.add(item);
        this.isDirty = true;
    }
    reportingAdd(item) {
        if (this.itemsSet.has(item)) {
            return false;
        }
        this.itemsSet.add(item);
        this.isDirty = true;
        return true;
    }
    delete(item) {
        const deletedItem = this.itemsSet.delete(item);
        this.isDirty || (this.isDirty = deletedItem);
        return deletedItem;
    }
    has(item) {
        return this.itemsSet.has(item);
    }
    clear() {
        this.isDirty || (this.isDirty = this.itemsSet.size > 0);
        this.itemsSet.clear();
    }
    getArray() {
        if (this.isDirty) {
            this.itemsArray = Array.from(this.itemsSet);
            this.isDirty = false;
        }
        return this.itemsArray;
    }
    getSet() {
        return this.itemsSet;
    }
}
//# sourceMappingURL=dirty-checked-unique-collection.js.map