import { TKeysOf } from "../typescript/t-keys-of.js";
import { TTypedArrayCtor } from "../array/typed-array/t-typed-array-ctor.js";
import { IDebugProtectedView } from "./i-debug-protected-view.js";
import { IEmscriptenWrapper } from "../web-assembly/emscripten/i-emscripten-wrapper.js";
/**
 * @public
 * Provides a view of an object that can be invalidated, causing attempts to access it to error in `_BUILD.DEBUG`.
 *
 * @remarks
 * Allows the specification of `safeKeys`, accessing of these is not an error regardless of invalidation state.
 */
export declare class DebugProtectedView<T extends object> implements IDebugProtectedView {
    readonly owningInstance: IEmscriptenWrapper<object>;
    private readonly debugInfo;
    private readonly safeKeys;
    static createTypedArrayView: <TCtor extends TTypedArrayCtor>(owningInstance: IEmscriptenWrapper<object>) => DebugProtectedView<InstanceType<TCtor>>;
    constructor(owningInstance: IEmscriptenWrapper<object>, debugInfo: string, safeKeys?: TKeysOf<T>);
    invalidate(): void;
    createProtectedView<T extends object>(view: T): T;
    static unwrapProtectedView<T extends object>(view: T): T;
    private validViews;
    private static isViewValidKey;
    private static originalViewKey;
    private static debugMessageKey;
}
