export class DebugWeakBroadcastEvent {
    constructor(key) {
        this.key = key;
        this.listenersSet = new Set();
        this.listenersMap = new WeakMap();
    }
    addListener(listener) {
        this.removeListener(listener);
        const ref = new WeakRef(listener);
        this.listenersSet.add(ref);
        this.listenersMap.set(listener, ref);
    }
    addTemporaryListener(listener) {
        this.addListener(listener);
        return () => this.removeListener(listener);
    }
    addOneTimeListener(listener) {
        const temporaryListener = {
            [this.key]: (...args) => {
                this.removeListener(temporaryListener);
                return listener[this.key](...args);
            }
        };
        this.addListener(temporaryListener);
        return () => this.removeListener(temporaryListener);
    }
    emit(...args) {
        this.listenersSet.forEach(ref => {
            const listener = ref.deref();
            if (listener == null) {
                this.listenersSet.delete(ref);
            }
            else {
                listener[this.key](...args);
            }
        });
    }
    removeListener(listener) {
        const ref = this.listenersMap.get(listener);
        if (ref != null) {
            this.listenersMap.delete(listener);
            this.listenersSet.delete(ref);
        }
    }
    getTargets() {
        const targets = [];
        this.listenersSet.forEach(ref => {
            const listener = ref.deref();
            if (listener == null) {
                this.listenersSet.delete(ref);
            }
            else {
                targets.push(listener);
            }
        });
        return targets;
    }
}
//# sourceMappingURL=debug-weak-broadcast-event.js.map