import { IReferenceCounted } from "./a-reference-counted.js";
/**
 * @public
 * Provides a mechanism reference counted objects to link to each other, respecting their lifecycles.
 */
export interface ILinkedReferences {
    /**
     * Link the ref, incrementing their reference counter.
     */
    linkRef(ref: IReferenceCounted): ILinkedReferences;
    /**
     * Unlink the ref, decrement their reference counter.
     */
    unlinkRef(ref: IReferenceCounted): ILinkedReferences;
    /**
     * Unlink all refs, decrement their reference counters.
     */
    unlinkAllRefs(): void;
    /**
     * @returns the refs that this object is linking to.
     */
    refsToArray(): readonly IReferenceCounted[];
}
/**
 * @public
 * {@inheritDoc ILinkedReferences}
 */
export declare class LinkedReferences implements ILinkedReferences {
    constructor(ref: IReferenceCounted);
    linkRef(ref: IReferenceCounted): ILinkedReferences;
    unlinkRef(ref: IReferenceCounted): ILinkedReferences;
    unlinkAllRefs(): void;
    private clearRefs;
    refsToArray(): readonly IReferenceCounted[];
    private refs;
    private readonly ref;
}
