import { DirtyCheckedUniqueCollection } from "../collection/dirty-checked-unique-collection.js";
import { _Debug } from "../debug/_debug.js";
/**
 * @public
 * {@inheritDoc ILinkedReferences}
 */
export class LinkedReferences {
    constructor(ref) {
        this.ref = ref;
        this.refs = new DirtyCheckedUniqueCollection();
    }
    linkRef(ref) {
        if (!this.refs.has(ref)) {
            if (_BUILD.DEBUG) {
                _Debug.assert(!DEBUG_getHasCycle(this.ref, ref), "detected cycle between references");
                _Debug.assert(!ref.getIsDestroyed() && !this.ref.getIsDestroyed(), "attempted to link to dead ref");
            }
            this.refs.add(ref);
            ref.claim();
        }
        return this;
    }
    unlinkRef(ref) {
        const removed = this.refs.delete(ref);
        if (removed) {
            ref.release();
        }
        return this;
    }
    unlinkAllRefs() {
        this.clearRefs();
    }
    clearRefs() {
        const refs = this.refs.getArray();
        for (let i = 0, iEnd = refs.length; i < iEnd; ++i) {
            refs[i].release();
        }
        this.refs.clear();
    }
    refsToArray() {
        return this.refs.getArray();
    }
}
function DEBUG_getHasCycle(referencingTo, referencingFrom) {
    if (referencingTo === referencingFrom) {
        return true;
    }
    const refs = referencingFrom
        .getLinkedReferences()
        .refsToArray();
    for (let i = 0, iEnd = refs.length; i < iEnd; ++i) {
        if (DEBUG_getHasCycle(referencingTo, refs[i])) {
            return true;
        }
    }
    return false;
}
//# sourceMappingURL=linked-references.js.map