/**
 * @public
 * Provides a communication channel via callbacks which can be easily cleared & copied.
 */
export interface ITemporaryListener<TArgs extends []> {
    /**
     * Emits an event and then clears the listeners.
     */
    clearingEmit(...args: TArgs): void;
    emit(...args: TArgs): void;
    clearListeners(): void;
    removeListener(listener: (...args: TArgs) => void): void;
    initializeListener(callback: () => ((...args: TArgs) => void)): void;
    addListener(listener: (...args: TArgs) => void): void;
    getTargets(): readonly ((...args: TArgs) => void)[];
}
/**
 * @public
 * {@inheritDoc ITemporaryListener}
 */
export declare class TemporaryListener<TArgs extends []> implements ITemporaryListener<TArgs> {
    clearingEmit(...args: TArgs): void;
    emit(...args: TArgs): void;
    clearListeners(): void;
    initializeListener(callback: () => ((...args: TArgs) => void)): void;
    addListener(listener: (...args: TArgs) => void): void;
    removeListener(listener: (...args: TArgs) => void): void;
    getTargets(): readonly ((...args: TArgs) => void)[];
    private listeners;
}
