import { DirtyCheckedUniqueCollection } from "../collection/dirty-checked-unique-collection.js";
/**
 * @public
 * {@inheritDoc ITemporaryListener}
 */
export class TemporaryListener {
    constructor() {
        this.listeners = new DirtyCheckedUniqueCollection();
    }
    clearingEmit(...args) {
        this.emit(...args);
        this.clearListeners();
    }
    emit(...args) {
        const listenerCallback = this.listeners.getArray();
        for (let i = 0, iEnd = listenerCallback.length; i < iEnd; ++i) {
            listenerCallback[i](...args);
        }
    }
    clearListeners() {
        this.listeners.clear();
    }
    initializeListener(callback) {
        this.listeners.add(callback());
    }
    addListener(listener) {
        this.listeners.add(listener);
    }
    removeListener(listener) {
        this.listeners.delete(listener);
    }
    getTargets() {
        return this.listeners.getArray();
    }
}
//# sourceMappingURL=temporary-listener.js.map