import { __awaiter } from "tslib";
import { shimWebAssemblyMemory } from "../util/shim-web-assembly-memory.js";
import { BroadcastEvent } from "../../eventing/broadcast-event.js";
import { _Debug } from "../../debug/_debug.js";
import { DebugWeakBroadcastEvent } from "../../debug/debug-weak-broadcast-event.js";
import { DebugSharedObjectLifeCycleChecker } from "../../debug/debug-shared-object-life-cycle-checker.js";
import { DebugWeakValue } from "../../debug/debug-weak-value.js";
import { arrayEmptyArray } from "../../array/impl/array-empty-array.js";
/**
 * @public
 * Factory for creating wrapped emscripten module.
 */
export function getEmscriptenWrapper(memory, emscriptenModuleFactory, extension = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const memoryListener = _BUILD.DEBUG
            ? new DebugWeakBroadcastEvent("onMemoryResize")
            : new BroadcastEvent("onMemoryResize");
        const debug = new EmscriptenDebug();
        if (_BUILD.DEBUG) {
            const debugInstance = extension;
            debugInstance.RC_JS_MEMORY_DEBUG_UTIL = debug;
        }
        const instance = yield emscriptenModuleFactory(Object.assign({ wasmMemory: memory }, extension));
        return new EmscriptenWrapper(memoryListener, instance, memory, debug);
    });
}
class EmscriptenWrapper {
    constructor(memoryResize, instance, memory, debug) {
        this.memoryResize = memoryResize;
        this.instance = instance;
        this.memory = memory;
        this.debug = debug;
        this.dataView = new DataView(memory.buffer);
        shimWebAssemblyMemory(memory, (buffer, previous, delta) => {
            _BUILD.DEBUG && _Debug.verboseLog(["WASM", "MEMORY"], `WebAssembly memory grew from ${previous} to ${previous + delta} pages.`);
            this.dataView = new DataView(this.memory.buffer);
            this.memoryResize.emit(buffer, previous, delta);
        });
    }
}
class EmscriptenDebug {
    constructor() {
        this.onAllocate = new DebugWeakBroadcastEvent("debugOnAllocate");
        this.protectedViews = new DebugWeakValue();
        this.sharedObjectLifeCycleChecks = new DebugSharedObjectLifeCycleChecker();
        this.uniquePointers = new Set();
    }
    error(message) {
        _Debug.error(message);
    }
    verboseLog(message, tags = arrayEmptyArray) {
        _Debug.verboseLog(tags, message);
    }
}
//# sourceMappingURL=get-emscripten-wrapper.js.map