import { _Debug } from "../../debug/_debug.js";
import { DebugProtectedView } from "../../debug/debug-protected-view.js";
import { ReferenceCountedPtr } from "../util/reference-counted-ptr.js";
import { DebugSharedObjectChecks } from "../util/debug-shared-object-checks.js";
/**
 * @public
 * Typed array representing static memory in wasm.
 */
export class SharedStaticArray {
    static createOneF32(wrapper, bindToReference, pointer, length) {
        const sta = new SharedStaticArray(Float32Array, wrapper, pointer, length);
        bindToReference === null || bindToReference === void 0 ? void 0 : bindToReference.linkRef(sta.sharedObject);
        return sta;
    }
    static createOneF64(wrapper, bindToReference, pointer, length) {
        const sta = new SharedStaticArray(Float64Array, wrapper, pointer, length);
        bindToReference === null || bindToReference === void 0 ? void 0 : bindToReference.linkRef(sta.sharedObject);
        return sta;
    }
    getInstance() {
        if (_BUILD.DEBUG) {
            _Debug.assert(!this.sharedObject.getIsDestroyed(), "access violation - object has been destroyed");
            return this.wrapper.debug.protectedViews
                .getValue(this)
                .createProtectedView(this.instance);
        }
        else {
            return this.instance;
        }
    }
    constructor(ctor, wrapper, pointer, length) {
        this.onMemoryResize = () => {
            this.instance = this.createLocalInstance();
        };
        this.sharedObject = new ReferenceCountedPtr(true, pointer, wrapper);
        this.length = length;
        this.ctor = ctor;
        this.wrapper = wrapper;
        this.elementByteSize = ctor.BYTES_PER_ELEMENT;
        _BUILD.DEBUG && _Debug.runBlock(() => {
            DebugSharedObjectChecks.registerWithCleanup(this, DebugProtectedView.createTypedArrayView(this.wrapper), "");
        });
        this.sharedObject.registerOnFreeListener(wrapper.memoryResize.addTemporaryListener(this));
        this.instance = this.createLocalInstance();
    }
    createLocalInstance() {
        return new this.ctor(this.wrapper.memory.buffer, this.sharedObject.getPtr(), this.length);
    }
}
//# sourceMappingURL=shared-static-array.js.map