import { ISharedObject } from "../../lifecycle/i-shared-object.js";
import { IDebugProtectedView } from "../../debug/i-debug-protected-view.js";
import { IDebugAllocateListener } from "../../debug/i-debug-allocate-listener.js";
/**
 * @public
 * Provides life cycle and access checks for shared objects.
 *
 * @remarks
 * `ProtectedViews` will be invalidated any time a memory resize might occur with standard `_BUILD.DEBUG` set.
 *
 * On garbage collect of the javascript object, the associated WASM pointer is checked to see if it has been disposed of.
 */
export declare class DebugSharedObjectChecks {
    /**
     * Calls register on the shared object but also registers the associated cleanup on release too.
     */
    static registerWithCleanup(instance: IDebugAllocateListener & ISharedObject, protectedView: IDebugProtectedView, nameOfInstance: string): IDebugProtectedView;
    static register(instance: IDebugAllocateListener & ISharedObject, protectedView: IDebugProtectedView, nameOfInstance: string): IDebugProtectedView;
    static unregister(protectedView: IDebugProtectedView, instance: {
        debugOnAllocate?: () => void;
    } & ISharedObject, nameOfInstance: string): void;
}
