import { AReferenceCounted } from "../../lifecycle/a-reference-counted.js";
import { _Debug } from "../../debug/_debug.js";
import { nullPointer } from "../emscripten/null-pointer.js";
import { lifecycleStack } from "../emscripten/lifecycle-stack.js";
/**
 * @public
 * Wrapper of wasm object.
 */
export class ReferenceCountedPtr extends AReferenceCounted {
    static createOneBound(bindToReference, isStatic, wasmPtr, wrapper) {
        const ptr = new ReferenceCountedPtr(isStatic, wasmPtr, wrapper);
        bindToReference === null || bindToReference === void 0 ? void 0 : bindToReference.linkRef(ptr);
        return ptr;
    }
    getPtr() {
        return this.wasmPtr;
    }
    /**
     * DO NOT CALL THIS DIRECTLY, CALL RELEASE.
     */
    onFree() {
        _BUILD.DEBUG && _Debug.runBlock(() => {
            this.wrapper.debug.uniquePointers.delete(this.wasmPtr);
        });
        super.onFree();
        this.wasmPtr = nullPointer;
    }
    constructor(isStatic, wasmPtr, wrapper) {
        super();
        this.isStatic = isStatic;
        this.wasmPtr = wasmPtr;
        this.wrapper = wrapper;
        lifecycleStack.register(this);
        _BUILD.DEBUG && _Debug.runBlock(() => {
            _Debug.assert(this.wasmPtr !== nullPointer && this.wasmPtr != null, "expected pointer to object but got null pointer");
            if (!this.isStatic) {
                _Debug.assert(!this.wrapper.debug.uniquePointers.has(this.wasmPtr), "expected pointer to be unique");
                this.wrapper.debug.uniquePointers.add(this.wasmPtr);
            }
        });
    }
}
//# sourceMappingURL=reference-counted-ptr.js.map